@@ -9,5 +9,5 @@ test.get.smiles2 <- function() {
   m1 <- parse.smiles("CCCNCC")[[1]]
   m2 <- parse.smiles("CNCCS")[[1]]
   mcs <- get.mcs(m1, m2)
-  checkEquals("[CH2]NCC", get.smiles(mcs, type='unique'))
+  checkEquals("[CH2]NCC", get.smiles(mcs, smiles.flavors(c('Unique'))))
 }
